@@ -48,6 +48,14 @@ def if_empty(object):
             return True
     return False
 
+def validate_str_input(payload):
+    for key, value in payload.items():
+        if not value:
+            return False
+        else:
+            if type(value) is not str:
+                return False
+    return True
 
 def object_mapper(object, result):
     mapped_object = {}
